@@ -218,7 +218,9 @@ class InterfaceFileHandling:
             credential=self.sas_token
         )
 
-        os.makedirs(self.settings.download_location, exist_ok=True)
+        path_to_file = os.path.dirname(filename)
+        download_path_for_file = os.path.join(self.settings.download_location, path_to_file)
+        os.makedirs(download_path_for_file, exist_ok=True)
         download_file_path = os.path.join(self.settings.download_location, filename)
         print("\nDownloading blob to \n\t" + download_file_path)
 
